@@ -33,6 +33,7 @@ class OverkizCommand(str, Enum):
     REFRESH_VENTILATION_STATE = "refreshVentilationState"
     RING_WITH_SINGLE_SIMPLE_SEQUENCE = "ringWithSingleSimpleSequence"
     SET_ABSENCE_MODE = "setAbsenceMode"
+    SET_ACTIVE_MODE = "setActiveMode"
     SET_AIR_DEMAND_MODE = "setAirDemandMode"
     SET_ALARM_STATUS = "setAlarmStatus"
     SET_ALL_MODE_TEMPERATURES = "setAllModeTemperatures"
@@ -51,8 +52,10 @@ class OverkizCommand(str, Enum):
     SET_FORCE_HEATING = "setForceHeating"
     SET_HEATING_LEVEL = "setHeatingLevel"
     SET_INTENSITY = "setIntensity"
+    SET_MANU_AND_SET_POINT_MODES = "setManuAndSetPointModes"
     SET_MEMORIZED_1_POSITION = "setMemorized1Position"
     SET_MEMORIZED_SIMPLE_VOLUME = "setMemorizedSimpleVolume"
+    SET_OPERATING_MODE = "setOperatingMode"
     SET_ORIENTATION = "setOrientation"
     SET_PEDESTRIAN_POSITION = "setPedestrianPosition"
     SET_RGB = "setRGB"
@@ -84,6 +87,7 @@ class OverkizCommandParam(str, Enum):
     BOOST = "boost"
     COMFORT = "comfort"
     CLOSED = "closed"
+    COOLING = "cooling"
     DEAD = "dead"
     DETECTED = "detected"
     DISARMED = "disarmed"
@@ -93,6 +97,7 @@ class OverkizCommandParam(str, Enum):
     FROSTPROTECTION = "frostprotection"
     FULL = "full"
     GEOFENCING_MODE = "geofencingMode"
+    HEATING = "heating"
     HIGH = "high"
     HIGH_DEMAND = "high demand"  # not a typo...
     HIGHEST = "highest"
